@@ -75,7 +75,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
 
   def __show_settings_dialog(self, button=None):
     self.__config.load()
-    settings_dialog = gtk.Dialog('%s' % (self.app_name), None, 
+    settings_dialog = gtk.Dialog(self.app_name, None, 
                                  gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, 
                                  self.__config_ui.get_dialog_buttons())
     wpa = gtk.VBox()
